==> spip_3.2.11.orig.tar.xz: ecrire/lang/public_he.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/public?lang_cible=he
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'accueil_site' => 'ראשי', # MODIF
	'articles' => 'מאמרים',
	'articles_auteur' => 'מאמרים של אותו המחבר',
	'articles_populaires' => 'המאמרים הפופולרים ביותר ',
	'articles_rubrique' => 'המאמרים של המדור',
	'aucun_article' => 'אין מאמר בכתובת זו',
	'aucun_auteur' => 'אין מחבר בכתובת זו',
	'aucun_site' => 'אין אתר בכתובת זו',
	'aucune_breve' => 'אין מבזק בכתובת זו',
	'aucune_rubrique' => 'אין מדור בכתובת זו',
	'autres' => 'אחר',
	'autres_breves' => 'מבזקים אחרים',
	'autres_groupes_mots_clefs' => 'קבוצות אחרות של מילות מפתח',
	'autres_sites' => 'אתרים אחרים',

	// B
	'bonjour' => 'שלום',

	// C
	'commenter_site' => 'הוספת תגובה לאתר',
	'copie_document_impossible' => 'לא מצליח להעתיק מסמך',

	// D
	'date' => 'תאריך',
	'dernier_ajout' => 'הוספה אחרונה',
	'dernieres_breves' => 'מבזקים אחרונים',
	'derniers_articles' => 'מאמרים אחרונים',
	'derniers_commentaires' => 'תגובות אחרונות',
	'derniers_messages_forum' => 'הודעות אחרונות בפורום',

	// E
	'edition_mode_texte' => 'הוצאה באורח טקסט של ',
	'en_reponse' => 'בתגובה ל :',
	'en_resume' => 'בסיכום',
	'envoyer_message' => 'שלח הודעה',
	'espace_prive' => 'אזור פרטי',

	// F
	'formats_acceptes' => 'פורמטים מקובלים: : @formats@.',

	// H
	'hierarchie_site' => 'מדרג האתר',

	// J
	'jours' => 'ימים',

	// L
	'lien_connecter' => 'כניסה',

	// M
	'meme_auteur' => 'מאת אותו המחבר',
	'meme_rubrique' => 'באותו המדור',
	'memes_auteurs' => 'מאת אותם המחברים',
	'message' => 'הודעה',
	'messages_forum' => 'הודעות הפורום', # MODIF
	'messages_recents' => 'ההודעות החדשות בפורום',
	'mots_clefs' => 'מילות מפתח',
	'mots_clefs_meme_groupe' => 'מילות מפתח מאותה קבוצה',

	// N
	'navigation' => 'דפדוף',
	'nom' => 'שם',
	'nouveautes' => 'חדשות',
	'nouveautes_web' => 'חדשות מן הרשת',
	'nouveaux_articles' => 'מאמרים חדשים',
	'nouvelles_breves' => 'מבזקים חדשים',

	// P
	'page_precedente' => 'לדף הקודם',
	'page_suivante' => 'לדף הבא',
	'par_auteur' => 'מאת',
	'participer_site' => 'אפשר להשתתף לפורומים של האתר ולהציע מאמרים לפרסום אך ורק תהליך ההרשמה. הפרטים לכניסה יישלחו לך בדרך דוא"ל. ',
	'plan_site' => 'מפת האתר',
	'popularite' => 'פופולריות',
	'poster_message' => 'הוספת הודעה',
	'proposer_site' => 'ניתן לך להציע אתר להוספה במדור זה :',

	// R
	'repondre_article' => 'הוספת תגובה למאמר',
	'repondre_breve' => 'הוספת תגובה למבזק',
	'resultats_recherche' => 'תוצאות החיפוש',
	'retour_debut_forums' => 'חזרה לדף הראשי של הפורומים',
	'rubrique' => 'מדור',
	'rubriques' => 'מדורים',

	// S
	'signatures_petition' => 'חתימות',
	'site_realise_avec_spip' => 'האתר בנוי עם מערכת ניהול התוכן SPIP',
	'sites_web' => 'אתרים ברשת',
	'sous_rubriques' => 'מדורים משניים',
	'spam' => 'דואר זבל',
	'suite' => 'המשך',
	'sur_web' => 'ברשת',
	'syndiquer_rubrique' => 'איחוד למדור זה',
	'syndiquer_site' => 'איחוד לאתר כולו',

	// T
	'texte_lettre_information' => 'להלן מכתב החדשות של האתר',
	'texte_lettre_information_2' => 'מכתב זה כולל כל המאמרים והמבזקים שפורסמו מאז', # MODIF

	// V
	'ver_imprimer' => 'גירסה להדפסה',
	'voir_en_ligne' => 'לתוכן מקוון',
	'voir_squelette' => 'לראות את השלד של דף זה'
);

==> spip_4.4.6+dfsg.orig.tar.xz: ecrire/lang/public_he.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/public?lang_cible=he
// ** ne pas modifier le fichier **

return [

	// A
	'accueil_site' => 'ראשי', # MODIF
	'articles' => 'מאמרים',
	'articles_auteur' => 'מאמרים של אותו המחבר',
	'articles_populaires' => 'המאמרים הפופולרים ביותר ',
	'articles_rubrique' => 'המאמרים של המדור',
	'aucun_article' => 'אין מאמר בכתובת זו',
	'aucun_auteur' => 'אין מחבר בכתובת זו',
	'aucun_site' => 'אין אתר בכתובת זו',
	'aucune_breve' => 'אין מבזק בכתובת זו',
	'aucune_rubrique' => 'אין מדור בכתובת זו',
	'autres' => 'אחר',
	'autres_breves' => 'מבזקים אחרים',
	'autres_groupes_mots_clefs' => 'קבוצות אחרות של מילות מפתח',
	'autres_sites' => 'אתרים אחרים',

	// B
	'bonjour' => 'שלום',

	// C
	'commenter_site' => 'הוספת תגובה לאתר',
	'copie_document_impossible' => 'לא מצליח להעתיק מסמך',

	// D
	'date' => 'תאריך',
	'dernier_ajout' => 'הוספה אחרונה',
	'dernieres_breves' => 'מבזקים אחרונים',
	'derniers_articles' => 'מאמרים אחרונים',
	'derniers_commentaires' => 'תגובות אחרונות',
	'derniers_messages_forum' => 'הודעות אחרונות בפורום',

	// E
	'edition_mode_texte' => 'הוצאה באורח טקסט של ',
	'en_reponse' => 'בתגובה ל :',
	'en_resume' => 'בסיכום',
	'envoyer_message' => 'שלח הודעה',
	'espace_prive' => 'אזור פרטי',

	// F
	'formats_acceptes' => 'פורמטים מקובלים: : @formats@.',

	// H
	'hierarchie_site' => 'מדרג האתר',

	// J
	'jours' => 'ימים',

	// L
	'lien_connecter' => 'כניסה',

	// M
	'meme_auteur' => 'מאת אותו המחבר',
	'meme_rubrique' => 'באותו המדור',
	'memes_auteurs' => 'מאת אותם המחברים',
	'message' => 'הודעה',
	'messages_forum' => 'הודעות הפורום', # MODIF
	'messages_recents' => 'ההודעות החדשות בפורום',
	'mots_clefs' => 'מילות מפתח',
	'mots_clefs_meme_groupe' => 'מילות מפתח מאותה קבוצה',

	// N
	'navigation' => 'דפדוף',
	'nom' => 'שם',
	'nouveautes' => 'חדשות',
	'nouveautes_web' => 'חדשות מן הרשת',
	'nouveaux_articles' => 'מאמרים חדשים',
	'nouvelles_breves' => 'מבזקים חדשים',

	// P
	'page_precedente' => 'לדף הקודם',
	'page_suivante' => 'לדף הבא',
	'par_auteur' => 'מאת',
	'participer_site' => 'אפשר להשתתף לפורומים של האתר ולהציע מאמרים לפרסום אך ורק תהליך ההרשמה. הפרטים לכניסה יישלחו לך בדרך דוא"ל. ',
	'plan_site' => 'מפת האתר',
	'popularite' => 'פופולריות',
	'poster_message' => 'הוספת הודעה',
	'proposer_site' => 'ניתן לך להציע אתר להוספה במדור זה :',

	// R
	'repondre_article' => 'הוספת תגובה למאמר',
	'repondre_breve' => 'הוספת תגובה למבזק',
	'resultats_recherche' => 'תוצאות החיפוש',
	'retour_debut_forums' => 'חזרה לדף הראשי של הפורומים',
	'rubrique' => 'מדור',
	'rubriques' => 'מדורים',

	// S
	'signatures_petition' => 'חתימות',
	'site_realise_avec_spip' => 'האתר בנוי עם מערכת ניהול התוכן SPIP',
	'sites_web' => 'אתרים ברשת',
	'sous_rubriques' => 'מדורים משניים',
	'spam' => 'דואר זבל',
	'suite' => 'המשך',
	'sur_web' => 'ברשת',
	'syndiquer_rubrique' => 'איחוד למדור זה',
	'syndiquer_site' => 'איחוד לאתר כולו',

	// T
	'texte_lettre_information' => 'להלן מכתב החדשות של האתר',
	'texte_lettre_information_2' => 'מכתב זה כולל כל המאמרים והמבזקים שפורסמו מאז', # MODIF

	// V
	'ver_imprimer' => 'גירסה להדפסה',
	'voir_en_ligne' => 'לתוכן מקוון',
	'voir_squelette' => 'לראות את השלד של דף זה',
];
